ACTION_CREATED = 'created'
ACTION_UPDATED = 'updated'
ACTION_DELETED = 'deleted'
ACTION_OTHER = 'other'
ACTION_CHOICES = (
    (ACTION_CREATED, ACTION_CREATED),
    (ACTION_UPDATED, ACTION_UPDATED),
    (ACTION_DELETED, ACTION_DELETED),
    (ACTION_OTHER, ACTION_OTHER),
)

LOG_LEVEL_CRITICAL = 'CRITICAL'
LOG_LEVEL_ERROR = 'ERROR'
LOG_LEVEL_WARNING = 'WARNING'
LOG_LEVEL_INFO = 'INFO'
LOG_LEVEL_DEBUG = 'DEBUG'
LOG_LEVEL_NOTSET = 'NOTSET'
LOG_LEVEL_CHOICES = (
    (LOG_LEVEL_CRITICAL, LOG_LEVEL_CRITICAL),
    (LOG_LEVEL_ERROR, LOG_LEVEL_ERROR),
    (LOG_LEVEL_WARNING, LOG_LEVEL_WARNING),
    (LOG_LEVEL_INFO, LOG_LEVEL_INFO),
    (LOG_LEVEL_DEBUG, LOG_LEVEL_DEBUG),
    (LOG_LEVEL_NOTSET, LOG_LEVEL_NOTSET),
)
